@@ -1,27 +1,10 @@
 package Image::Info::GIF;
-$VERSION = '1.01';
 
 # Copyright 1999-2000, Gisle Aas.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-=begin register
-
-MAGIC: /^GIF8[79]a/
-
-Both GIF87a and GIF89a are supported and the version number is found
-as C<GIF_Version> for the first image.  GIF files can contain multiple
-images, and information for all images will be returned if
-image_info() is called in list context.  The Netscape-2.0 extension to
-loop animation sequences is represented by the C<GIF_Loop> key for the
-first image.  The value is either "forever" or a number indicating
-loop count.
-
-=end register
-
-=cut
-
 use strict;
 
 sub my_read
@@ -30,7 +13,7 @@ sub my_read
     my $buf;
     my $n = read($source, $buf, $len);
     die "read failed: $!" unless defined $n;
-    die "short read ($len/$n) at pos " . tell($source) unless $n == $len;
+    die "short read ($len/$n)" unless $n == $len;
     $buf;
 }
 
@@ -89,17 +72,14 @@ sub process_file
     $info->push_info(0, "file_ext" => "gif");
 
     # more??
-    if ($global_color_table) {
-       my $color_table = my_read($fh, $color_table_size * 3);
-       #$info->push_info(0, "GlobalColorTable", color_table($color_table));
-    }
+    my $color_table = my_read($fh, $color_table_size * 3);
+    #$info->push_info(0, "GlobalColorTable", color_table($color_table));
 
     my $img_no = 0;
     my @comments;
     my @warnings;
 
     while (1) {
-	last if eof($fh); # EOF
 	my $intro = ord(my_read($fh, 1));
 	if ($intro == 0x3B) {  # trailer (end of image)
 	    last;
