@@ -1,31 +1,12 @@
 package Image::Info::PNG;
 
-# Copyright 1999-2000, Gisle Aas.
+# Copyright 1999-200, Gisle Aas.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-=begin register
-
-MAGIC: /^\x89PNG\x0d\x0a\x1a\x0a/
-
-Information from IHDR, PLTE, gAMA, pHYs, tEXt, tIME chunks are
-extracted.  The sequence of chunks are also given by the C<PNG_Chunks>
-key.
-
-=end register
-
-=cut
-
 use strict;
 
-# Test for Compress::Zlib (for reading zTXt chunks)
-my $have_zlib = 0;
-eval {
-    require Compress::Zlib;
-    $have_zlib++;
-};
-
 sub my_read
 {
     my($source, $len) = @_;
@@ -103,7 +84,7 @@ sub process_file
 		push(@table, sprintf("#%02x%02x%02x",
 				     unpack("C3", substr($data, 0, 3, ""))));
 	    }
-	    $info->push_info(0, "ColorPalette" => \@table);
+	    $info->push_info(0, "RGB_Palette" => \@table);
 	}
 	elsif ($type eq "gAMA" && $len == 4) {
 	    $info->push_info(0, "Gamma", unpack("N", $data)/100_000);
@@ -135,15 +116,6 @@ sub process_file
 	    # other key we might generate
 	    $info->push_info(0, $key, $val);
 	}
-	elsif ($type eq "zTXt" && $have_zlib) {
-		my($key, $val) = split(/\0/, $data, 2);
-		my($method,$ctext) = split(//, $val, 2);
-		if ($method eq "\0") {
-		    $info->push_info(0, $key, Compress::Zlib::uncompress($ctext));
-		} else {
-		    $info->push_info(0, "Chunk-$type" => $data);
-		}
-	}
 	elsif ($type eq "tIME" && $len == 7) {
 	    $info->push_info(0, "LastModificationTime",
 			     sprintf("%04d-%02d-%02d %02d:%02d:%02d",
